.. hubugs documentation master file, created by
   sphinx-quickstart on Mon May 31 20:00:36 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _hubugs-label:

.. module:: hubugs

:mod:`hubugs`
==============

:mod:`hubugs` is a very simple client for working with `GitHub's issue
tracker`_ from the command line.

It is written in Python_, and requires v2.6 or later.  :mod:`hubugs` is
released under the `GPL v3`_

:Git repository:  https://github.com/JNRowe/hubugs/
:Issue tracker:  https://github.com/JNRowe/hubugs/issues/
:Contributors:  https://github.com/JNRowe/hubugs/contributors/

Contents
--------

.. toctree::
   :maxdepth: 2

   background
   install
   config
   usage
   templates
   hubugs manpage <hubugs.1>
   faq
   alternatives
   appendix

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _Github's issue tracker: http://github.com/blog/411-github-issue-tracker
.. _Python: http://www.python.org/
.. _GPL v3: http://www.gnu.org/licenses/
